package com.perforce.workshop.tjuricek.p4java_ext;

import com.perforce.p4java.exception.P4JavaException;
import com.perforce.p4java.server.IOptionsServer;

import java.util.Map;

/**
 * Access to the "p4 triggers" command. Generally only run by a super user
 * during initialization of a new Perforce server.
 */
public interface P4Triggers extends P4Connection, P4Errors {

    static P4Triggers create(P4Connection conn) {
        return new DefaultP4Triggers(conn);
    }

    default TriggerSpec load() {
        try {
            IOptionsServer server = getOptionsServer();

            String[] opts = {"-o"};

            Map<String, Object>[] results =
                    server.execMapCmd("triggers", opts, null);

            checkError(results);

            if (results.length != 1) {
                throw new IllegalStateException("results.length != 1");
            }

            return new TriggerSpec(results[0]);

        } catch (P4JavaException e) {
            throw new P4Exception(e);
        }
    }

    default void save(TriggerSpec triggerSpec) {
        try {
            IOptionsServer server = getOptionsServer();

            String[] opts = {"-i"};

            // Please note that we are using an input string here due to a
            // known issue in p4java: P4JAVA-835 job071702
            Map<String, Object>[] results =
                    server.execInputStringMapCmd("triggers", opts,
                            triggerSpec.triggersMapAsSpec());

            checkError(results);

        } catch (P4JavaException e) {
            throw new P4Exception(e);
        }
    }
}
